geowatch.demo.metrics\_demo.demo\_rendering module
==================================================

.. automodule:: geowatch.demo.metrics_demo.demo_rendering
   :members:
   :undoc-members:
   :show-inheritance:
